Learn R Programming

summclust (version 0.7.2)

vcov_CR3J: Compute CRV3 covariance matrices via a cluster jackknife as described in MacKinnon, Nielsen & Webb (2022)

Description

Compute CRV3 covariance matrices via a cluster jackknife as described in MacKinnon, Nielsen & Webb (2022)

Usage

vcov_CR3J(obj, ...)

Value

An object of type 'vcov_CR3J'

Arguments

obj

An object of class lm or fixest computed?

...

misc function argument

References

MacKinnon, James G., Morten Ørregaard Nielsen, and Matthew D. Webb. "Leverage, influence, and the jackknife in clustered regression models: Reliable inference using summclust." arXiv preprint arXiv:2205.03288 (2022).

See Also

vcov_CR3J.lm, vcov_CR3J.fixest

Examples

Run this code

library(summclust)
data(mtcars)
mtcars

fit <- lm(mpg ~ cyl + disp + hp, data = mtcars)
summ <- vcov_CR3J(fit, cluster = ~carb)

Run the code above in your browser using DataLab