Learn R Programming

summclust (version 0.7.2)

vcov_CR3J.lm: Compute CRV3 covariance matrices via a cluster jackknife as described in MacKinnon, Nielsen & Webb (2022) for objects of type lm

Description

Compute CRV3 covariance matrices via a cluster jackknife as described in MacKinnon, Nielsen & Webb (2022) for objects of type lm

Usage

# S3 method for lm
vcov_CR3J(obj, cluster, type = "CRV3", return_all = FALSE, ...)

Value

An object of class vcov_CR3J

Arguments

obj

An object of type lm

cluster

A clustering vector

type

"CRV3" or "CRV3J" following MacKinnon, Nielsen & Webb. CRV3 by default

return_all

Logical scalar, FALSE by default. Should only the vcov be returned (FALSE) or additional results (TRUE)

...

other function arguments passed to 'vcov'

References

MacKinnon, James G., Morten Ørregaard Nielsen, and Matthew D. Webb. "Leverage, influence, and the jackknife in clustered regression models: Reliable inference using summclust." arXiv preprint arXiv:2205.03288 (2022).

Examples

Run this code

library(summclust)
data(mtcars)
mtcars

fit <- lm(mpg ~ cyl + disp + hp, data = mtcars)
summ <- vcov_CR3J(fit, cluster = ~carb)
library(summclust)
data(mtcars)
mtcars

fit <- lm(mpg ~ cyl + disp + hp, data = mtcars)
summ <- vcov_CR3J(fit, cluster = ~carb)

Run the code above in your browser using DataLab