summclust.fixest: Compute Influence and Leverage Metrics for objects of type fixest
Description
Compute influence and leverage metrics for clustered inference
based on the Cluster Jackknife as described in MacKinnon, Nielsen & Webb
(2022) for objects of type fixest.
Usage
# S3 method for fixest
summclust(
obj,
cluster,
params,
absorb_cluster_fixef = TRUE,
type = "CRV3",
...
)
Value
An object of type summclust, including
a CRV3 variance-covariance estimate as described in
MacKinnon, Nielsen & Webb (2022)
coef_estimates
The coefficient estimates of the linear model.
vcov
A CRV3 or CRV3J variance-covariance matrix estimate
as described in MacKinnon, Nielsen & Webb (2022)
leverage_g
A vector of leverages.
leverage_avg
The cluster leverage.
partial_leverage
The partial leverages.
coef_var_leverage_avg
Coefficient of Variation for the leverage
statistic
coef_var_leverage_g
Coefficient of Variation for the Partial
Leverage Statistics
coef_var_N_G
Coefficient of Variation for the Cluster Sizes.
beta_jack
The jackknifed' leave-on-cluster-out
regression coefficients.
params
The input parameter vector 'params'.
N_G
The number of clusters-
call
The summclust() function call.
cluster
The names of the clusters.
Arguments
obj
An object of type fixest
cluster
A clustering vector
params
A character vector of variables for which leverage statistics
should be computed. If NULL, leverage statistics will be computed for all
k model covariates
absorb_cluster_fixef
TRUE by default. Should the cluster fixed
effects be projected out? This increases numerical stability and
decreases computational costs
type
"CRV3" or "CRV3J" following MacKinnon, Nielsen & Webb
...
other function arguments passed to 'vcov'
References
MacKinnon, James G., Morten Ørregaard Nielsen, and Matthew D. Webb.
"Leverage, influence, and the jackknife in clustered regression models:
Reliable inference using summclust."
arXiv preprint arXiv:2205.03288 (2022).