tidy.summclust: S3 method to summarize objects of class boottest into tidy data.frame
Description
Obtain results from a summclust object in a tidy data frame.
Usage
# S3 method for summclust
tidy(x, ...)
Value
A data.frame containing coefficient estimates,
t-statistics, standard errors, p-value, and confidence
intervals based on CRV3 variance-covariance matrix
and t(G-1) distribution
Arguments
x
An object of class 'summclust'
...
Other arguments
References
MacKinnon, James G., Morten Ørregaard Nielsen, and Matthew D. Webb.
"Leverage, influence, and the jackknife in clustered regression models:
Reliable inference using summclust."
arXiv preprint arXiv:2205.03288 (2022).